FlutterQjsLogger class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

enabled bool
getter/setter pair
handler FlutterQjsLogHandler?
getter/setter pair
level FlutterQjsLogLevel
getter/setter pair

Static Methods

debug(String message, [Object? error]) → void
error(String message, [Object? error]) → void
info(String message, [Object? error]) → void
log(FlutterQjsLogLevel logLevel, String message, [Object? error]) → void
warning(String message, [Object? error]) → void