JsEnginePoolConfig class

Configuration for engines created by JsEnginePool.

Constructors

JsEnginePoolConfig({int stackSize = 1024 * 1024, int? timeout, int? memoryLimit = kDefaultJsMemoryLimit, EngineResetMode resetMode = EngineResetMode.none, bool resetOnRelease = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
memoryLimit int?
final
resetMode EngineResetMode
Isolation strategy between leases. Default EngineResetMode.none.
final
resetOnRelease bool
When true, equivalent to EngineResetMode.hard if resetMode is omitted (see constructor). Prefer setting resetMode explicitly.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackSize int
final
timeout int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited