JSTypedArrayType class

JSTypedArrayEnum values (order matches quickjs.h).

Constructors

JSTypedArrayType()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

BIG_INT64 → const int
BIG_UINT64 → const int
FLOAT16 → const int
FLOAT32 → const int
FLOAT64 → const int
INT8 → const int
INT16 → const int
INT32 → const int
UINT8 → const int
UINT8C → const int
UINT16 → const int
UINT32 → const int