JsMemoryUsage class

Snapshot of QuickJS JSMemoryUsage fields used for monitoring.

Constructors

JsMemoryUsage({required int mallocSize, required int mallocLimit, required int memoryUsedSize, required int mallocCount, required int memoryUsedCount, required int atomCount, required int atomSize, required int strCount, required int strSize, required int objCount, required int objSize, required int propCount, required int propSize})
const

Properties

atomCount int
final
atomSize int
final
hashCode int
The hash code for this object.
no setterinherited
mallocCount int
final
mallocLimit int
final
mallocSize int
final
memoryUsedCount int
final
memoryUsedSize int
final
objCount int
final
objSize int
final
propCount int
final
propSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strCount int
final
strSize int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited