IsolateQjs class

Constructors

IsolateQjs({_JsAsyncModuleHandler? moduleHandler, int? stackSize, int? timeout, int? memoryLimit, _JsHostPromiseRejectionHandler? hostPromiseRejectionHandler})
Quickjs engine runing on isolate thread.

Properties

hashCode int
The hash code for this object.
no setterinherited
hostPromiseRejectionHandler → _JsHostPromiseRejectionHandler?
Handler function to manage js module.
final
memoryLimit int?
Max memory for quickjs.
final
moduleHandler → _JsAsyncModuleHandler?
Asynchronously handler to manage js module.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackSize int?
Max stack size for quickjs.
final
timeout int?
Max stack size for quickjs.
final

Methods

close() Future?
Free Runtime and close isolate thread that can be recreate when evaluate again.
evaluate(String command, {String? name, int? evalFlags}) Future
Evaluate js script.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHostFunctions(Map<String, Function> functions) → void
Register host functions callable from JS as globalThis[name](...).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited